@@ -3,12 +3,22 @@ import sys
 from tabulate import tabulate
 from novaclient.exceptions import AuthorizationFailure, Unauthorized
 
-from cmds import Clone, Images, List, Desalt, Emancipate, Delete
+from cmds import (
+    Clone,
+    Delete,
+    Desalt,
+    Emancipate,
+    Images,
+    List,
+    Start,
+    Stop,
+)
 from colors import red
 
 from errors import (
     CommandExecutionError,
     ConnectionFailure,
+    CredentialError,
     InvalidCommandArgs,
     WrapperFailure,
 )
@@ -24,12 +34,14 @@ CMDS = {
     'images': Images,
     'list': List,
     'rm': Delete,
+    'start': Start,
+    'stop': Stop,
 }
 
 
 def fetch_command(cmd, **kwargs):
     if cmd == "--help":
-        print "usage: stackctl [--help] <command> [<args>]\n"
+        print "usage: stackctl [--help] <command> [<args>, --force]\n"
         print tabulate([[name, cmd.__doc__ ] for name, cmd in CMDS.iteritems()])
     elif cmd in CMDS:
         return CMDS[cmd](**kwargs)
@@ -47,10 +59,9 @@ def main(args, **kwargs):
     except AttributeError:
         pass
     except (AuthorizationFailure, Unauthorized):
-        print red("Authentication Failed!")
-        print source_msg
-    except errors as e:
-        print e.message
+        msg = red("Authentication Failed!\n")
+        msg += source_msg
+        raise CredentialError(msg)
 
 
 def run(cmd, *args, **kwargs):
